@@ -3,6 +3,16 @@
 #Could make bounce effect when hit boundaries by sending in opposite direction for count down moment
 #could make accelrate faster by using previuos x,y as well as start x,y as startx,y means you cant accelerate until back to starting point.
 
+#               Display a circle around the food as its hard to see in new background = animate
+#               Delete toy with real background
+#               Become immortal again one collect toy
+#19.05.10    Use png instead of jpg for sprites so colorkey does not distort
+#               Fix food outside screen size bug
+#               Background image - Thanks lil-mz!! - http://lil-mz.deviantart.com/art/Jungle-Background-125967963?offset=0
+#               Fix recurring toy bug
+#               Make food bigger / easier to hit
+#               Tweek toys given
+#18.05.10    Animate the toy
 #               Save level high score scored at
 #               Increase fps from 60 to 30
 #               Change max_accel based on level no
@@ -35,6 +45,7 @@ import pygame.mixer
 debug_line = ""
 DEBUG_ON_DIE = 0
 debug_xy = 0
+DEBUG_MODE = 0
 
 #Consts
 fps=30
@@ -48,11 +59,11 @@ map_accel = 1
 accel_x=0
 accel_y=0
 accel_delay = 0
-toy_slow_rate = 5
+toy_slow_rate = 6
 screen_x = 800
 screen_y = 440
-food_size = 20
-toy_size = 20
+food_size = 34
+toy_size = 34
 snapy_size = 32
 snapy_char = "."
 blank_char = "*"
@@ -106,6 +117,13 @@ death_high = 0
 immortal = immortal_period
 mixer = pygame.mixer
 toys = 0
+toy_sprite = 1
+toy_ani = 1
+toy_frms = 4
+circ_ani = 1
+circ_frms = 4
+circ_frm_rate = 2   #1 = fastest
+circ_frm_rate_count = 1
 snapy_length = 0
 bg_bright = 0
 red = 128
@@ -121,6 +139,13 @@ backwash_miny =[1]*(max_backwash+1)
 backwash_maxy=[1]*(max_backwash+1)
 paused = 0
 
+if DEBUG_MODE == 1:
+    unit_speed=.25
+    speed= 2          #Speed can be float and move will occur in integers
+    level_speed = speed
+    
+
+
 line=blank_char*screen_x
 print "Generating Map..."
 map = [line]*screen_y
@@ -731,6 +756,53 @@ def death_march():
     new_high_score = 0
     print "leave the death march.."
 
+def animate():
+    #Animation effects
+    global toy_sprite , toy_ani,  toy_frms,  toys,  toy_x,  toy_y,  toy1,  toy2,  toy3,  toy4
+    global current_circ,  circ_rect , circ_ani,  circ_frms,  food_x,  food_y,  food
+    global circ1,  circ2,  circ3,  circ4,  background,  circ_frm_rate,  circ_frm_rate_count
+
+    #Food circle
+    if circ_frm_rate_count <= 1:
+        circ_frm_rate_count = circ_frm_rate
+        #Which frame to display?
+        circ_ani = circ_ani + 1
+        if circ_ani > circ_frms:
+            circ_ani = 1
+        
+        if circ_ani == 1:
+            current_circ = circ1
+        elif circ_ani == 2:
+            current_circ = circ2
+        elif circ_ani == 3:
+            current_circ = circ3
+        else:
+            current_circ = circ4 
+        #First blit the background as the circle contains transparent bits that would show through previous frames
+        screen.blit(background,(food_x - 8, food_y - 8),circ_rect)
+        #Blit the circle to show where the food is
+        screen.blit(current_circ, (food_x - 8, food_y - 8))
+        #Blit the food on top
+        screen.blit(food, (food_x , food_y))
+    else:
+        circ_frm_rate_count = circ_frm_rate_count - 1
+
+    #Animate toy if active
+    if toys == 1:
+        toy_ani = toy_ani + 1
+        if toy_ani > (toy_frms * 2):
+            toy_ani = 1
+        
+        if toy_ani == 1 or toy_ani == 2:
+            screen.blit(toy1, (toy_x,toy_y))
+        elif toy_ani == 3 or toy_ani == 4:
+            screen.blit(toy2, (toy_x,toy_y))
+        elif toy_ani == 5 or toy_ani == 6:
+            screen.blit(toy3, (toy_x,toy_y))
+        else:
+            screen.blit(toy4, (toy_x,toy_y))                
+
+
 def eat_or_die():
     #See if snake is eating food
     #If so increment food counter, vibrate, reset new food
@@ -738,7 +810,8 @@ def eat_or_die():
     global food_x, food_y, food_score, food_no, food_char, x, y, food_size, map,  left, right,  speed, accel_x,  accel_y, DEBUG_ON_DIE
     global bumper_size ,  death_detail, snapy_size,  snapy_char,  map_accel, immortal, immortal_period,  bg_channel
     global toy_char,  toy_size,  toy_x,  toy_y,  toys,  blank_snapy,  score,  high_score,  snapy_length,  time_score
-    global high_score3,  level_score,  level_speed, unit_speed, max_accel,  toy_slow_rate
+    global high_score3,  level_score,  level_speed, unit_speed, max_accel,  toy_slow_rate, background,  white
+    global food_rect,  toy_rect,  background,  snapy,  circ_rect,  food
     
     count = y + 31
     happy_meal = 0
@@ -758,23 +831,23 @@ def eat_or_die():
     
     #TOYS
     if toys == 1:
-        print "Toys are in the pram..."
+        #print "Toys are in the pram..."
         count = y + 31
         toy_slice = toy_char*toy_size
         while ((count > y-2) ):
             if map[count][x:x+toy_size] <> toy_slice:
                 if map[count][x:x+toy_size].find(toy_char) > -1:
                     #We found a toy!
-                    print "found a toy!"
+                    #print "found a toy!"
                     toy_time = 1
                     break
-            
             count = count -1
+            
     if toy_time == 1:
         #Toy resets speed to slowest
         level_speed = level_speed - (unit_speed * toy_slow_rate)
-        if level_speed < unit_speed + int(food_no / 5):
-            level_speed = unit_speed + int(food_no / 5)
+        if level_speed < unit_speed + int(food_no / 10):
+            level_speed = unit_speed + int(food_no / 10)
         speed = level_speed
         accel_x = 0
         accel_y = 0
@@ -790,14 +863,17 @@ def eat_or_die():
         sound = mixer.Sound(sfx_file)
         #start playing
         channel = sound.play()
-        #clear 
-        screen.blit(blank_snapy, (toy_x,toy_y))
+        #clear toy
+        #print str(toy_rect) + str(food_rect)+ str(toy_x) + str(toy_y)
+        image_part = toy_rect         #(10,10,30,30) # left,top,width,height of image area
+        screen.blit(background,(toy_x, toy_y),image_part)
         #score 5 X food points!
         food_score = food_score + (food_no * 5)
+        immortal = immortal_period
 
     
     
-    if happy_meal == 0 and toy_time ==0:
+    if happy_meal == 0 and toy_time ==0 and immortal ==0:
         ################
         #Check for the grim reaper
         ################
@@ -844,6 +920,7 @@ def eat_or_die():
             
         if funeral == 1:
             print "death by canabalism"
+            toys = 0
             food_score = 0
             time_score = 0
             snapy_length = 0
@@ -921,6 +998,7 @@ def eat_or_die():
             #reset acceleration
             accel_x = 0
             accel_y = 0
+            toys = 0
 
 
             
@@ -929,21 +1007,25 @@ def eat_or_die():
         snapy_length = 0
         
         #Clear screen
-        screen.fill(black)
+        #screen.fill(black)
+        screen.blit(background, (0,0))
         
         #New food
-        food_x = random.randint(0, screen_x-32)
-        food_y = random.randint(0, screen_y-32)
-        rnd_no = random.randint(1, 4)
-        food = pygame.image.load("/home/opt/snapy/images/food" + str(rnd_no) + ".jpg").convert()
+        food_x = random.randint(0, screen_x-(food_size + 8))
+        food_y = random.randint(0, screen_y-(food_size + 8))
+        rnd_no = random.randint(1, 6)
+        food = pygame.image.load("/home/opt/snapy/images/food" + str(rnd_no) + ".png").convert()
+        food.set_colorkey(white, pygame.RLEACCEL)
         screen.blit(food, (food_x,food_y))
-        if speed > (unit_speed * 8):
-            if rnd_no < 2:
+                
+        if speed > (unit_speed * 4):
+            if rnd_no < 3:
                 #Create a toy
                 toys = 1
-                toy_x = random.randint(0, screen_x-32)
-                toy_y = random.randint(0, screen_y-32)
-                toy = pygame.image.load("/home/opt/snapy/images/toy.jpg").convert()
+                toy_x = random.randint(64, screen_x-64)
+                toy_y = random.randint(64, screen_y-64)
+                toy = pygame.image.load("/home/opt/snapy/images/toy11.png").convert()
+                toy.set_colorkey(white, pygame.RLEACCEL)
                 screen.blit(toy, (toy_x,toy_y))
                 sfx_file = "/home/opt/snapy/sfx/rattle.wav"
                 print sfx_file
@@ -956,10 +1038,16 @@ def eat_or_die():
         map = [line]*screen_y
         print "Map generated..."
         map_food(food_x, food_y)
+        food_rect.left,  food_rect.top = food_x,  food_y
         if toys == 1:
             map_toy(toy_x, toy_y)
+            toy_rect.left,  toy_rect.top = toy_x,  toy_y
         map_me(x, y)
+        circ_rect.left = food_rect.left -8          #Food is 32x , circle is 48x
+        circ_rect.top = food_rect.top - 8
         immortal = immortal_period
+        #Update whole screen to clear old snapy!
+        pygame.display.update()
         
     
 debug_line = "open"
@@ -974,6 +1062,7 @@ pygame.init()
 #Defaults
 size = width, height = screen_x, screen_y
 black = 0, 0, 0
+white = 255, 255, 255
 debug_line = "Get rotation"
 write_file()
 #Rotation Defaults
@@ -982,29 +1071,73 @@ str_ac = get_rotation()
 cx = ax
 cy = ay
 #Setup screen
-screen = pygame.display.set_mode(size)
-screen.fill(black)
 pygame.mouse.set_visible(0)
+screen = pygame.display.set_mode(size)
+#screen.fill(black)
+background = pygame.image.load("/home/opt/snapy/images/bg.jpg").convert()
 
 
-snapy = pygame.image.load("/home/opt/snapy/images/head.jpg").convert()
-snapy.set_colorkey(black, RLEACCEL)
-immortal_snapy = pygame.image.load("/home/opt/snapy/images/immortal_head.jpg").convert()
-immortal_snapy.set_colorkey(black, RLEACCEL)
+snapy = pygame.image.load("/home/opt/snapy/images/head.png").convert()
+snapy.set_colorkey(white, RLEACCEL)
+snapy_rect = snapy.get_rect()
+immortal_snapy = pygame.image.load("/home/opt/snapy/images/immortal_head.png").convert()
+immortal_snapy.set_colorkey(white, RLEACCEL)
+immortal_rect = immortal_snapy.get_rect()
 blank_snapy = pygame.image.load("/home/opt/snapy/images/blank_head.jpg").convert()
+blank_rect = blank_snapy.get_rect()
 
-food = pygame.image.load("/home/opt/snapy/images/food" + str(random.randint(1, 4)) + ".jpg").convert()
-food_x = random.randint(0, screen_x-32)
-food_y = random.randint(0, screen_y-32)
+#Load toy animations
+toy1 = pygame.image.load("/home/opt/snapy/images/toy11.png").convert()
+toy2 = pygame.image.load("/home/opt/snapy/images/toy12.png").convert()
+toy3 = pygame.image.load("/home/opt/snapy/images/toy13.png").convert()
+toy4 = pygame.image.load("/home/opt/snapy/images/toy14.png").convert()
+toy1.set_colorkey(white, pygame.RLEACCEL)
+toy_rect = toy1.get_rect()
+toy2.set_colorkey(white, pygame.RLEACCEL)
+toy3.set_colorkey(white, pygame.RLEACCEL)
+toy4.set_colorkey(white, pygame.RLEACCEL)
+
+#Load food circle animations
+circ1 = pygame.image.load("/home/opt/snapy/images/circq1.png").convert()
+circ2 = pygame.image.load("/home/opt/snapy/images/circq2.png").convert()
+circ3 = pygame.image.load("/home/opt/snapy/images/circq3.png").convert()
+circ4 = pygame.image.load("/home/opt/snapy/images/circq4.png").convert()
+circ1.set_colorkey(white, pygame.RLEACCEL)
+circ_rect = circ1.get_rect()
+circ2.set_colorkey(white, pygame.RLEACCEL)
+circ3.set_colorkey(white, pygame.RLEACCEL)
+circ4.set_colorkey(white, pygame.RLEACCEL)
+
+#Display the back ground then the food
+food = pygame.image.load("/home/opt/snapy/images/food" + str(random.randint(1, 4)) + ".png").convert()
+food.set_colorkey(white, pygame.RLEACCEL)
+food_x = random.randint(0, screen_x-(food_size + 8))
+food_y = random.randint(0, screen_y-(food_size + 8))
+screen.blit(background, (0,0))
 screen.blit(food, (food_x,food_y))
+food_rect = food.get_rect()
+food_rect.left,  food_rect.top = food_x,  food_y
 map_food(food_x, food_y)
 
+#Then the circle around the food now was have food center
+current_circ = circ1
+circ_rect.left = food_rect.left -8          #Food is 32x , circle is 48x
+circ_rect.top = food_rect.top - 8
+print str(circ_rect) + str(food_rect)
+screen.blit(current_circ, (circ_rect.left, circ_rect.top))
+
+
 
 #We get rotaion again so we know the direction we are travelling before we start collision detection
 str_ac = get_rotation()
 
 #uncomment to run in FullScreen Mode
 #pygame.display.toggle_fullscreen()
+blit_list = [snapy_rect]
+blit_list.append(food_rect)
+blit_list.append(immortal_rect)
+#Load entire background first or we will have no bg image!
+#pygame.display.update(blit_list)
 pygame.display.flip()
 
 #Initial background sfx
@@ -1086,15 +1219,29 @@ while 1:
         eat_or_die()    
 
 
-        #Draw me
+        #Draw me - circle rect always contains the food rect
+        blit_list = [circ_rect]
+        #pygame.display.update(blit_list)
         if immortal > 0:
             screen.blit(immortal_snapy, (x, y))
+            immortal_rect = immortal_snapy.get_rect()
+            immortal_rect.left,  immortal_rect.top = x, y
             immortal = immortal - 1
+            blit_list.append(immortal_rect)
+            #print "i:" + str(immortal_rect) + str(food_rect)
         else:
             screen.blit(snapy, (x,y))
+            snapy_rect = snapy.get_rect()
+            snapy_rect.left,  snapy_rect.top = x, y
+            blit_list.append(snapy_rect)
+            #print "s:" + str(snapy_rect)+ str(food_rect)
             #Place me on map
             map_me(x, y)
-
+        
+        #if toys == 1:
+        toy_rect.left,  toy_rect.top = toy_x,  toy_y
+        blit_list.append(toy_rect)
+    
         if debug_xy == 1:
             pygame.display.set_caption ("x:" + str(x) + " y:" + str(y) + " ax:" + str(accel_x) + " ay:" + str(accel_y)) 
         else:
@@ -1107,7 +1254,8 @@ while 1:
 
         #button1rect = button1.get_rect()
         #print "accel: " + str_ac  + str(accel_x)
-        pygame.display.flip()
+        animate()
+        pygame.display.update(blit_list)
         
     else:
         pygame.display.set_caption ("PAUSED! - hit p to continue...." + "Snapy!! Score:" + str(score) ) 
@@ -1115,7 +1263,7 @@ while 1:
     q = 0
     w = 0
     for event in pygame.event.get():
-        print "accel: " + str(az) + ":" + str(ay) + ""
+        #print "accel: " + str(az) + ":" + str(ay) + ""
         if event.type == pygame.QUIT:
             sys.exit()
         elif event.type == KEYDOWN and event.key == K_ESCAPE:
